from django.apps import AppConfig


class WagtailContentImportMicrosoftPickerAppConfig(AppConfig):
    name = 'wagtail_content_import.pickers.microsoft'
    label = 'wagtail_content_import_microsoft_picker'
    verbose_name = "Wagtail Content Import - Microsoft Picker"
