from django.apps import AppConfig


class WagtailContentImportGooglePickerAppConfig(AppConfig):
    name = 'wagtail_content_import.pickers.google'
    label = 'wagtail_content_import_google_picker'
    verbose_name = "Wagtail Content Import - Google Picker"
